==> apache-tez-0.7.0-src.tar.gz: apache-tez-0.7.0-src/tez-dag/src/main/java/org/apache/tez/dag/app/dag/event/TaskAttemptEventContainerTerminatedBySystem.java <==
/**
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance
* with the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package org.apache.tez.dag.app.dag.event;

import org.apache.tez.dag.records.TaskAttemptTerminationCause;
import org.apache.tez.dag.records.TezTaskAttemptID;

public class TaskAttemptEventContainerTerminatedBySystem extends TaskAttemptEvent 
  implements DiagnosableEvent, TaskAttemptEventTerminationCauseEvent {

  private final String diagnostics;
  private final TaskAttemptTerminationCause errorCause;
  public TaskAttemptEventContainerTerminatedBySystem(TezTaskAttemptID id, String diagnostics,
      TaskAttemptTerminationCause errorCause) {
    super(id, TaskAttemptEventType.TA_CONTAINER_TERMINATED_BY_SYSTEM);
    this.diagnostics = diagnostics;
    this.errorCause = errorCause;
  }

  @Override
  public String getDiagnosticInfo() {
    return diagnostics;
  }

  @Override
  public TaskAttemptTerminationCause getTerminationCause() {
    return errorCause;
  }
}

==> apache-tez-0.10.0-src.tar.gz: apache-tez-0.10.0-src/tez-dag/src/main/java/org/apache/tez/dag/app/dag/event/TaskAttemptEventContainerTerminatedBySystem.java <==
/**
* Licensed to the Apache Software Foundation (ASF) under one
* or more contributor license agreements.  See the NOTICE file
* distributed with this work for additional information
* regarding copyright ownership.  The ASF licenses this file
* to you under the Apache License, Version 2.0 (the
* "License"); you may not use this file except in compliance
* with the License.  You may obtain a copy of the License at
*
*     http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

package org.apache.tez.dag.app.dag.event;

import org.apache.hadoop.yarn.api.records.ContainerId;
import org.apache.tez.dag.records.TaskAttemptTerminationCause;
import org.apache.tez.dag.records.TezTaskAttemptID;

public class TaskAttemptEventContainerTerminatedBySystem extends TaskAttemptEvent 
  implements DiagnosableEvent, TaskAttemptEventTerminationCauseEvent {

  private final ContainerId containerId;
  private final String diagnostics;
  private final TaskAttemptTerminationCause errorCause;

  public TaskAttemptEventContainerTerminatedBySystem(ContainerId containerId, TezTaskAttemptID id,
      String diagnostics, TaskAttemptTerminationCause errorCause) {
    super(id, TaskAttemptEventType.TA_CONTAINER_TERMINATED_BY_SYSTEM);
    this.containerId = containerId;
    this.diagnostics = diagnostics;
    this.errorCause = errorCause;
  }

  public ContainerId getContainerId() {
    return containerId;
  }

  @Override
  public String getDiagnosticInfo() {
    return diagnostics;
  }

  @Override
  public TaskAttemptTerminationCause getTerminationCause() {
    return errorCause;
  }
}
